<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hy">
<context>
    <name>AppSelectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="42"/>
        <source>Check transfer application will automatically install the corresponding UOS version of the application.</source>
        <translation>Ստուգել տրանսֆեր ծրագիրը ավտոմատ կարգավորում է համապատասխան ՈՒՕՍ տարբերակը ծրագրի համար</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="56"/>
        <source>Confirm</source>
        <translation>Հաստատել</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Չեղարկել</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="77"/>
        <source>Application</source>
        <translation>Ծրագիր</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="77"/>
        <source>Recommendation</source>
        <translation>Առաջարկ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="102"/>
        <source>Transferable</source>
        <translation>Տրանսֆերաբիլ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="112"/>
        <source>Not Suitable</source>
        <translation>Անհարմար</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.h" line="46"/>
        <source>Select apps to transfer</source>
        <translation>Ընտրեք ծրագրեր տրանսֆերի համար</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.h" line="47"/>
        <source>Please select the applications to back up</source>
        <translation>Խնդրում ենք ընտրեք ծրագրերը արխիվավորելու համար</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <location filename="../../src/apps/data-transfer/main.cpp" line="86"/>
        <source>UOS data transfer</source>
        <translation>ՈՒՕՍ տվյալների տրանսֆերը</translation>
    </message>
    <message>
        <location filename="../../src/apps/data-transfer/main.cpp" line="91"/>
        <source>UOS transfer tool enables one click migration of your files, personal data, and applications to UOS, helping you seamlessly replace your system.</source>
        <translation>ՈՒՕՍ տրանսֆերային առաքիչը թույլ է տալիս մի կտրուկ տեղափոխում ձեր ֆայլերը, անձնական տվյալները և ծրագրերը ՈՒՕՍ համակարգի համար, օգնելով ձեր համակարգը հարмонիկ կերպով փոխարինել</translation>
    </message>
</context>
<context>
    <name>ChooseWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.h" line="35"/>
        <source>Export to local directory</source>
        <translation>Արտահանել տեղական կատալոգ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.cpp" line="41"/>
        <source>Select a transfer way</source>
        <translation>Ընտրեք տրանսֆերի մեթոդը</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.cpp" line="56"/>
        <source>Unable to connect to the network， please check your network connection or select export to local directory.</source>
        <translation>Ցանկացած կապ ցանկացած ցանցի կապով կարող է ապահովվել, խնդրում ենք ստուգեք ցանցի կապը կամ ընտրեք տեղական կատալոգի արտահանումը</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.cpp" line="69"/>
        <source>Next</source>
        <translation>Հաջորդը</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.h" line="33"/>
        <source>From Windows PC</source>
        <translation>Հանրային համակարգից</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.h" line="39"/>
        <source>Import from backup files</source>
        <translation>Իմպորտել արխիվավորված ֆայլերից</translation>
    </message>
</context>
<context>
    <name>ConfigSelectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="39"/>
        <source>Check transfer configuration will automatically apply to UOS.</source>
        <translation>Ստուգել տրանսֆերի կարգավորումը ավտոմատ կարգավորում է ՈՒՕՍ համակարգի համար</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="51"/>
        <source>Confirm</source>
        <translation>Հաստատել</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="49"/>
        <source>Cancel</source>
        <translation>Չեղարկել</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="75"/>
        <source>Browser bookmarks</source>
        <translation>Բրաուզերի նշանակումները</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="75"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="116"/>
        <source>Recommendation</source>
        <translation>Առաջարկ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="98"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="139"/>
        <source>Transferable</source>
        <translation>Տրանսֆերաբիլ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="116"/>
        <source>Personal Settings</source>
        <translation>Անձնական կարգավորումները</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="138"/>
        <source>Customized Wallpaper</source>
        <translation>Անձնական հիմնարար պատկերը</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.h" line="49"/>
        <source>Select the configuration to transfer</source>
        <translation>Ընտրեք կարգավորումը տրանսֆերի համար</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.h" line="50"/>
        <source>Please select the configurations to back up</source>
        <translation>Խնդրում ենք ընտրեք կարգավորումները արխիվավորելու համար</translation>
    </message>
</context>
<context>
    <name>ConnectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="36"/>
        <source>Ready to connect</source>
        <translation>Գտրվում է կապի համար</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="41"/>
        <source>Please open data transfer on Windows, and imput the IP and connect code</source>
        <translation>Խնդրում ենք բացեք տվյալների տրանսֆերը Windows-ում և մուտքագրեք IP-ը և կապի կոդը</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="48"/>
        <source>Download Windows client</source>
        <translation>Բերեք Windows հաճախագրի տեսակը</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="59"/>
        <source>Connect code is expired, please refresh for new code</source>
        <translation>Կոդը ավարտվել է, խնդրում ենք վերստացնել նոր կոդ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="75"/>
        <source>Back</source>
        <translation>Վերադառնալ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="104"/>
        <source>computer</source>
        <translation>համակարգիչ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="107"/>
        <source>Local IP</source>
        <translation>տեղական IP</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="163"/>
        <source>Refresh</source>
        <translation>Վերստացնել</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="171"/>
        <source>The code will be expired in</source>
        <translation>Կոդը ավարտվի հետևյալ ընթացքում</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="171"/>
        <source>please input connect code as soon as possible</source>
        <translation>Խնդրում ենք միացման կոդը անմիջապես մուտքագրել</translation>
    </message>
</context>
<context>
    <name>CreateBackupFileWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="87"/>
        <source>Create data backup</source>
        <translation>Տվյալների պատկերացուցակ ստեղծել</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="95"/>
        <source>File information</source>
        <translation>Ֆայլի տեղեկություններ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="115"/>
        <source>Name</source>
        <translation>Անվանում</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="133"/>
        <source>size:0B</source>
        <translation>չափումը: 0Բ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="152"/>
        <source>Location</source>
        <translation>Տեղաբաշխում</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="162"/>
        <source>(Select Backup Disk)</source>
        <translation>(Ընտրել պատկերացուցակի սկզբնական սեղմակտոր)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="187"/>
        <source>Insufficient space in the selected disk, please clean the space</source>
        <translation>Ընտրված սեղմակտորում բավարար տարածք չկա, խնդրում ենք ազատացնել տարածքը</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="195"/>
        <source>Backup</source>
        <translation>Պատկերացուցակ ստեղծել</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="193"/>
        <source>Cancel</source>
        <translation>Չեղարկել</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="339"/>
        <source>Size:%1</source>
        <translation>Չափումը:%1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="382"/>
        <source>local disk</source>
        <translation>տեղական սեղմակտոր</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="388"/>
        <source>%1/%2 available</source>
        <translation>&apos;%1/%2 առաջարկվում է&apos;</translation>
    </message>
</context>
<context>
    <name>CustomMessageBox</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="66"/>
        <source>Reselect</source>
        <translation>Ընտրել վերադարձի միանման</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="81"/>
        <source>Continue</source>
        <translation>Շարունակել</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="138"/>
        <source>The presence of outstanding transfer tasks between you and the target device has been detected.</source>
        <translation>&gt;-
 Այլաբանջային փոխանցման աշխատանքների առկայությունը ձեռք բերվել է ձեր և ավելի հարուստ փոխանցման աշխատանքների միջև:</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="138"/>
        <source>Do you want to continue with the last transfer?</source>
        <translation>Շարունակել վերջին փոխանցումը կամ ոչ?</translation>
    </message>
</context>
<context>
    <name>ErrorWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.cpp" line="54"/>
        <source>Transfer will be completed in</source>
        <translation>Փոխանցումը կավարտվի հետևյալ ընթացքում</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.cpp" line="69"/>
        <source>Try again</source>
        <translation>Փորձել նորից</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.cpp" line="66"/>
        <source>Back</source>
        <translation>Վերադառնալ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="29"/>
        <source>Network Error</source>
        <translation>Ռետելների սխալ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="30"/>
        <source>Transfer interrupted</source>
        <translation>Փոխանցումը անցական տվյալների փոխանցումը ավարտվել է</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="32"/>
        <source>The network disconnected, transfer failed, please connect the network and try again</source>
        <translation>&gt;-
 Ռետելները կապված չէ, փոխանցումը չհաջողվեց, խնդրում ենք կապվել ռետելների հետ և փորձել նորից</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="34"/>
        <source>Insufficient space in UOS, please clear at least %1 GB and try again</source>
        <translation>UOS-ում բավարար տարածք չկա, խնդրում ենք ազատ անել առնվազն միայն %1 ԳԲ և փորձել նորից</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="36"/>
        <source>Insufficient space in UOS, Please reserve enough space</source>
        <translation>տարածությունը բացակայում է, խնդրում ենք ապահովել բավարար տարածություն</translation>
    </message>
</context>
<context>
    <name>FileSelectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="50"/>
        <source>Name</source>
        <translation>Անուն</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="50"/>
        <source>Size</source>
        <translation>Չափս</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="60"/>
        <source>When transfer completed, the data will be placed in the user&apos;s home directory</source>
        <translation>Փոխանցումը ավարտելուց հետո տվյալները կտեղադրվեն օգտագործողի տունը կատարելափոխված հասցեում</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="73"/>
        <source>Confirm</source>
        <translation>Հաստատել</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="71"/>
        <source>Cancel</source>
        <translation>Չեղարկել</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.h" line="56"/>
        <source>Select the file to transfer</source>
        <translation>Ընտրեք փոխանցումի համար անհրաժեշտ անունը</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.h" line="57"/>
        <source>Please select the files to back up</source>
        <translation>Խնդրում ենք ընտրեք արխիվացման համար անհրաժեշտ անունները</translation>
    </message>
</context>
<context>
    <name>NetworkDisconnectionWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/networkdisconnectionwidget.cpp" line="34"/>
        <source>The network has been disconnected. Please check your network</source>
        <translation>Շանսային առարկան դադարեցված է, խնդրում ենք ստուգեք ձեր հաղորդացողական ցանցը</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/networkdisconnectionwidget.cpp" line="40"/>
        <source>Back</source>
        <translation>Վերադառնալ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/networkdisconnectionwidget.cpp" line="41"/>
        <source>Try again</source>
        <translation>Փորձել նորից</translation>
    </message>
</context>
<context>
    <name>ProcessWindow</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="297"/>
        <source>Installing</source>
        <translation>Ծանրաբար ստանդարտացնել</translation>
    </message>
</context>
<context>
    <name>PromptWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="29"/>
        <source>Before tranfer</source>
        <translation>Փոխանցումից առաջ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="34"/>
        <source>Data transfer requires some time, to avoid interrupting the migration due to low battery, please keep connect to the  power.</source>
        <translation>Փոխանցումը պահանջու՞ղ է ժամանակ, հանգստացնելու համար միգրացիան անընդհատ մնա, խնդրում ենք միգրացիան անընդհատ մնա, խնդրում ենք պահել կապը էլեկտրական հոսանքի հետ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="36"/>
        <source>Other applications may slowdown the transfer speed. For smoother experience, please close other applications.</source>
        <translation>Այլ ծրագրերը կկանգարկեն փոխանցման արագությունը, հարուստ փոխանցում ապահովելու համար խնդրում ենք փակեք այլ ծրագրերը</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="38"/>
        <source>For the security of your transfer, please use a trusted network.</source>
        <translation>Ձեր փոխանցման անվտանգության համար խնդրում ենք օգտագործել արտաքին ցանց</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="62"/>
        <source>Back</source>
        <translation>Վերադառնալ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="64"/>
        <source>Confirm</source>
        <translation>Հաստատել</translation>
    </message>
</context>
<context>
    <name>ReadyWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="48"/>
        <source>Ready to connect</source>
        <translation>Կապ ստանձնելու համար պատրաստ եք</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="52"/>
        <source>IP</source>
        <translation>ԻՊ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="59"/>
        <source>Please input the IP of UOS</source>
        <translation>Խնդրում ենք մուտքագրեք UOS-ի ԻՊ-ն</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="79"/>
        <source>Please open data transfer on UOS, and get the IP</source>
        <translation>Խնդրում ենք բացեք տվյալների փոխանցումը UOS-ում և ստացեք ԻՊ-ն</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="85"/>
        <source>Connect code</source>
        <translation>Կապի կոդ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="95"/>
        <source>Please input the connect code on UOS</source>
        <translation>Խնդրում ենք մուտքագրեք կապի կոդը UOS-ում</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="118"/>
        <source>Back</source>
        <translation>Վերադառնալ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="33"/>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="112"/>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="167"/>
        <source>connect...</source>
        <translation>կապ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="120"/>
        <source>Connect</source>
        <translation>Կապ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="258"/>
        <source>Failed to connect, please check your input</source>
        <translation>Կապը չի ստացվել, խնդրում ենք ստուգեք ձեր մուտքագրումը</translation>
    </message>
</context>
<context>
    <name>ResultDisplayWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="128"/>
        <source>Transfer completed partially</source>
        <translation>Փոխանցումը մասաբար ավարտված է</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="32"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="125"/>
        <source>Transfer completed</source>
        <translation>Փոխանցումը ավարտված է</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="38"/>
        <source>Partial information migration failed, please go to UOS for manual transfer</source>
        <translation>հանգամանքը անկատար է, խորանալ համակարգի համար ձեւակերպել ձեւակերպական ձեւակերպումը</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="50"/>
        <source>Back</source>
        <translation>Վերադառնալ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="52"/>
        <source>Exit</source>
        <translation>Ելք</translation>
    </message>
</context>
<context>
    <name>SelectItem</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="216"/>
        <source>Selected:0</source>
        <translation>Ընտրված:0</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="237"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="239"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="241"/>
        <source>Selected:%1</source>
        <translation>Ընտրված:%1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="304"/>
        <source>Edit</source>
        <translation>Խմբագրել</translation>
    </message>
</context>
<context>
    <name>SelectMainWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="90"/>
        <source>File</source>
        <translation>Ֆայլ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="95"/>
        <source>App</source>
        <translation>Ապպ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="97"/>
        <source>Config</source>
        <translation>Կոնֆիգ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="112"/>
        <source>Back</source>
        <translation>Վերադառնալ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="72"/>
        <source>Select data to transfer</source>
        <translation>Ընտրել տրանսֆերի տվյալները</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="73"/>
        <source>Please select the content to back up</source>
        <translation>Խնդրում ենք ընտրել պահպանման համար պարունակությունը</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="74"/>
        <source>Start transfer</source>
        <translation>Սկսել տրանսֆերը</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="75"/>
        <source>Next</source>
        <translation>Հաջորդը</translation>
    </message>
</context>
<context>
    <name>SettingHelper</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="63"/>
        <source>Profiles</source>
        <translation>Փորտրեյտներ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="63"/>
        <source>Wrong or missing profile</source>
        <translation>Սխալ կամ բացակայող փորտրեյտ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="111"/>
        <source>My Wallpaper</source>
        <translation>Իմ պատկերասրահը</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="111"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="146"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="234"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="268"/>
        <source>Transfer completed</source>
        <translation>Տրանսֆերը ավարտված է</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="133"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="143"/>
        <source>Browser Bookmarks</source>
        <translation>Բրաուզերի հիշատակարանները</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="146"/>
        <source>BrowserBookMark</source>
        <translation>Բրաուզերի հիշատակարան</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="176"/>
        <source>is installed</source>
        <translation>է տեղադրված</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="200"/>
        <source>Installing</source>
        <translation>Տեղադրում է</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="268"/>
        <source>Transfer failed</source>
        <translation>Տրանսֆերը հնարավոր չէ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="133"/>
        <source>Format error</source>
        <translation>Ձևակերպման սխալ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="143"/>
        <source>Setup failed, configuration can be imported manually</source>
        <translation>Տեղադրումը հնարավոր չէ, կոնֆիգուրացիան կարող է ձեւակերպվել ձեւակերպական ձեւակերպումով</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="157"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="188"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="238"/>
        <source>Installation failed, please go to the app store to install</source>
        <translation>Տեղադրումը հնարավոր չէ, խորանալ կամ ապպ ստորաբաժանման համար</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="249"/>
        <source>Transfer Complete</source>
        <translation>Տրանսֆերը ավարտված է</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="21"/>
        <source>Videos</source>
        <translation>Տեսանյութեր</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="22"/>
        <source>Pictures</source>
        <translation>Պատկերներ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="23"/>
        <source>Documents</source>
        <translation>Փաստաթուղթներ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="24"/>
        <source>Downloads</source>
        <translation>Բացահայտումներ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="25"/>
        <source>Music</source>
        <translation>Երաժշտություն</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="26"/>
        <source>Desktop</source>
        <translation>Աշխատա檣ային պատուհան</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="80"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="351"/>
        <source>Select:%1</source>
        <translation>Ընտրել:%1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="225"/>
        <source>local disk</source>
        <translation>տեղական սկավառակ</translation>
    </message>
</context>
<context>
    <name>StartWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/startwidget.cpp" line="35"/>
        <source>UOS data transfer</source>
        <translation>ՈՒՕՍ տվյալների տեղափոխում</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/startwidget.cpp" line="39"/>
        <source>UOS transfer tool enables one click migration of your files, personal data, and applications to
UOS, helping you seamlessly replace your system.</source>
        <translation>ՈՒՕՍ տեղափոխման արագացուցիչը թույOR կտրում է ձեր ֆայլերը, անհատական տվյալները և ծրագրերը ՈՒՕՍ-ի համընդհանումով, օգնում է ձեր համակարգը անընդհատ փոխարինել</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/startwidget.cpp" line="46"/>
        <source>Next</source>
        <translation>Հաջորդ</translation>
    </message>
</context>
<context>
    <name>TransferHandle</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/transferworker.cpp" line="326"/>
        <source>Transfering</source>
        <translation>Տեղափոխում</translation>
    </message>
</context>
<context>
    <name>TransferringWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="42"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="193"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="230"/>
        <source>Transferring...</source>
        <translation>Տեղափոխում...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="57"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="191"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="229"/>
        <source>Calculationing...</source>
        <translation>Հաշվարկում...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="63"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="132"/>
        <source>Show processes</source>
        <translation>Ցույց տալ գործընթացները</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="119"/>
        <source>Hide processes</source>
        <translation>Անցույց տալ գործընթացները</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="154"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="195"/>
        <source>Transfer will be completed in %1 minutes</source>
        <translation>Տեղափոխումը կվերջանա %1 րոպեից հետո</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="171"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="237"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="243"/>
        <source>Transfering</source>
        <translation>Տեղափոխում</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="199"/>
        <source>Transfer will be completed in %1 secondes</source>
        <translation>Տեղափոխումը կվերջանա %1 վայրկյանից հետո</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="202"/>
        <source>Transfer will be completed in --</source>
        <translation>Տեղափոխումը կվերջանի --</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="237"/>
        <source>Decompressing</source>
        <translation>Բացատրաման</translation>
    </message>
</context>
<context>
    <name>UnzipWorker</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/unzipwoker.cpp" line="126"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/unzipwoker.cpp" line="137"/>
        <source>Decompressing</source>
        <translation>Բացատրամ անել</translation>
    </message>
</context>
<context>
    <name>UploadFileFrame</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="197"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="256"/>
        <source>Drag file here </source>
        <translation>Փոխանցեք ֆայլը այստեղ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="202"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="257"/>
        <source>Import file</source>
        <translation>Ֆայլ ներմուծել</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="276"/>
        <source>Only .zip is supported, please</source>
        <translation>Առանական հանդեպ համար միայն .zip ֆայլերն են աջակցվում, խնդրում ենք</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="277"/>
        <source>reselect</source>
        <translation>վերաընտրել</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="351"/>
        <source>select zip file</source>
        <translation>ընտրեք .zip ֆայլը</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="351"/>
        <source>ZIP file (*.zip)</source>
        <translation>ZIP ֆայլ (*.zip)</translation>
    </message>
</context>
<context>
    <name>UploadFileWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="40"/>
        <source>Select data transfer file</source>
        <translation>Ընտրեք տվյա料 տեղափոխման ֆայլը</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="49"/>
        <source>File error, cannot transfer, please reselect</source>
        <translation>Ֆայլի սխալ է, տեղափոխումը հնարավոր չէ, խնդրում ենք վերաընտրել</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="62"/>
        <source>Back</source>
        <translation>Վարձակալություն</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="64"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="108"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="113"/>
        <source>Next</source>
        <translation>Հաջորդ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="69"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="76"/>
        <source>Retry</source>
        <translation>Փորձել կրկին</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="122"/>
        <source>The file is corrupted and cannot be migrated. Please replace it with a backup file.</source>
        <translation>Նախագծի վրա բացակայում է անունը, և այն չի կարող տեղափոխվել: Խնդրում ենք փոխարինեք այն արխիվավորման ֆայլով։</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="133"/>
        <source>Insufficient space on UOS. Please reserve at least %1G of space and try again.</source>
        <translation>UOS-ի վրա բացակայում է տեղ անունը: Խնդրում ենք պահպանեք ամենաքիչը %1G տեղ և փորձեք նորից։</translation>
    </message>
</context>
<context>
    <name>UserSelectFileSize</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/userselectfilesize.cpp" line="22"/>
        <source>Calculating</source>
        <translation>Հաշվարկում ենք</translation>
    </message>
</context>
<context>
    <name>WaitTransferWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="32"/>
        <source>Waiting for transfer...</source>
        <translation>Շարունակում ենք տեղափոխում...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="37"/>
        <source>Please select the data to transfer on Windows</source>
        <translation>Խնդրում ենք ընտրեք տեղափոխելու տվյալները Windows-ի վրա</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="47"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="98"/>
        <source>Cancel</source>
        <translation>Չեղարկել</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="99"/>
        <source>Close</source>
        <translation>Փակել</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="101"/>
        <source>This operation will clear the transmission progress, Do you want to continue.</source>
        <translation>Այս գործողությունը կհանգեցնի տեղափոխման առաջադրանքի մասին տեղեկատվության մաքրման, ցանկանում եք շարունակել։</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="102"/>
        <source>This operation is not recoverable</source>
        <translation>Այս գործողությունը վերականգնելի չէ</translation>
    </message>
</context>
<context>
    <name>ZipFileProcessResultWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="32"/>
        <source>Exit</source>
        <translation>Ելք</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="49"/>
        <source>Back</source>
        <translation>Վերադառնալ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="84"/>
        <source>Back up succeed</source>
        <translation>Արխիվավորումը հաջողված է</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="90"/>
        <source>Congratulations, Your Information has been Successfully Backed Up.</source>
        <translation>Հաջողություն, ձեր տեղեկատվությունը հաջողությամբ արխիվավորված է</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="95"/>
        <source>Go to View</source>
        <translation>Շարունակել դիտելու համար</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="120"/>
        <source>Back up failed</source>
        <translation>Արխիվավորումը հանգստացրել է</translation>
    </message>
</context>
<context>
    <name>ZipFileProcessWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="44"/>
        <source>Packing  %1</source>
        <translation>Արխիվավորում %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="53"/>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="101"/>
        <source>Transfer will be completed in %1 minutes</source>
        <translation>ՏեղափՈխությունը կավարտվի %1 րոպեից հետո</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="56"/>
        <source>Transfer will be completed in %1 secondes</source>
        <translation>Տեղափոխությունը կավարտվի %1 վայրկյանից հետո</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="84"/>
        <source>Creating Backup File...</source>
        <translation>Արխիվավորման ֆայլի ստեղծում...</translation>
    </message>
</context>
<context>
    <name>ZipWork</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipworker.cpp" line="283"/>
        <source>%1 File compression failed</source>
        <translation>&apos;%1 ֆայլի սեղմումը հանգստացրէլ է&apos;</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipworker.cpp" line="213"/>
        <source>Back up file done</source>
        <translation>Արխիվավոր ֆայլը կատարված է</translation>
    </message>
</context>
<context>
    <name>data_transfer_core::MainWindowPrivate</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/linux/mainwindow_p_linux.cpp" line="32"/>
        <source>UOS data transfer</source>
        <translation>UOS տեղափոխությունը</translation>
    </message>
</context>
</TS>